==> virtuoso-opensource-6.1.3.tar.xz: virtuoso-opensource-6.1.3/libsrc/Wi/json_p.h <==

/* A Bison parser, made by GNU Bison 2.4.1.  */

/* Skeleton interface for Bison's Yacc-like parsers in C
   
      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.
   
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.
   
   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */


/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     OBJ_BEGIN = 258,
     OBJ_END = 259,
     ARR_BEGIN = 260,
     ARR_END = 261,
     COLON = 262,
     COMMA = 263,
     STRING = 264,
     NUMBER = 265,
     TRUE_L = 266,
     FALSE_L = 267,
     NULL_L = 268
   };
#endif
/* Tokens.  */
#define OBJ_BEGIN 258
#define OBJ_END 259
#define ARR_BEGIN 260
#define ARR_END 261
#define COLON 262
#define COMMA 263
#define STRING 264
#define NUMBER 265
#define TRUE_L 266
#define FALSE_L 267
#define NULL_L 268




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
{

/* Line 1676 of yacc.c  */
#line 39 "./json.y"

  caddr_t box;
  caddr_t *list;
  dk_set_t set;



/* Line 1676 of yacc.c  */
#line 86 "json_p.h"
} YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
#endif

extern YYSTYPE jsonyylval;

==> virtuoso-opensource-6.1.8.tar.xz: virtuoso-opensource-6.1.8/libsrc/Wi/json_p.h <==

/* A Bison parser, made by GNU Bison 2.4.1.  */

/* Skeleton interface for Bison's Yacc-like parsers in C
   
      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.
   
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.
   
   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */


/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     JSON_OBJ_BEGIN = 258,
     JSON_OBJ_END = 259,
     JSON_ARR_BEGIN = 260,
     JSON_ARR_END = 261,
     JSON_COLON = 262,
     JSON_COMMA = 263,
     JSON_NAME = 264,
     JSON_SQSTRING = 265,
     JSON_DQSTRING = 266,
     JSON_NUMBER = 267,
     JSON_TRUE_L = 268,
     JSON_FALSE_L = 269,
     JSON_NULL_L = 270
   };
#endif
/* Tokens.  */
#define JSON_OBJ_BEGIN 258
#define JSON_OBJ_END 259
#define JSON_ARR_BEGIN 260
#define JSON_ARR_END 261
#define JSON_COLON 262
#define JSON_COMMA 263
#define JSON_NAME 264
#define JSON_SQSTRING 265
#define JSON_DQSTRING 266
#define JSON_NUMBER 267
#define JSON_TRUE_L 268
#define JSON_FALSE_L 269
#define JSON_NULL_L 270




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
{

/* Line 1676 of yacc.c  */
#line 39 "./json.y"

  caddr_t box;
  caddr_t *list;
  dk_set_t revlist;



/* Line 1676 of yacc.c  */
#line 90 "json_p.h"
} YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
#endif

extern YYSTYPE jsonyylval;
